searchNodes=[{"ref":"PhoenixInlineSvg.Helpers.html","title":"PhoenixInlineSvg.Helpers","module":"PhoenixInlineSvg.Helpers","type":"module","doc":"This module adds view helpers for rendering SVG files into safe HTML. To add the helpers, add the following to the quoted view in your my_app_web.ex file. def view do quote do use PhoenixInlineSvg.Helpers, otp_app: :my_app end end This will generate functions for each of your images, effectively caching them at compile time. You can call these functions like so # Get an image with the default collection svg_image(&quot;image_name&quot;) # Get an image and insert HTML attributes to svg tag svg_image(&quot;image_name&quot;, class: &quot;elixir-is-awesome&quot;, id: &quot;inline-svg&quot;) # Get an image from a different collection svg_image(&quot;image_name&quot;, &quot;collection_name&quot;) # Get an image from a different collection and insert HTML attributes to the svg tag svg_image(&quot;image_name&quot;, &quot;collection_name&quot;, class: &quot;elixir-is-awesome&quot;, id: &quot;inline-svg&quot;) Old Way As an alternative this module can be imported in the quoted view def of the my_app_web.ex which will always pull the SVG files from the disk (unless you are using a caching module). def view do quote do import PhoenixInlineSvg.Helpers end end Note: If you are setting a custom directory for the SVG files and are using Exrm or Distillery, you will need to ensure that the directory you set is in the outputted lib directory of your application. Configuration By default SVG files are loaded from: priv/static/svg/ The directory where SVG files are loaded from can be configured by setting the configuration variable: config :phoenix_inline_svg, dir: &quot;some/other/dir&quot; Where some/other/dir is a directory located in the Phoenix application directory."},{"ref":"PhoenixInlineSvg.Helpers.html#__using__/1","title":"PhoenixInlineSvg.Helpers.__using__/1","module":"PhoenixInlineSvg.Helpers","type":"macro","doc":"The using macro precompiles the SVG images into functions. Using this macro requires passing your otp_app name as an argument. Examples # Default collection svg_image(&quot;image_name&quot;) svg_image(&quot;image_name&quot;, attrs) # Named collection svg_image(&quot;image_name&quot;, &quot;collection_name&quot;) svg_image(&quot;image_name&quot;, &quot;collection_name&quot;, attrs)"},{"ref":"PhoenixInlineSvg.Helpers.html#svg_image/2","title":"PhoenixInlineSvg.Helpers.svg_image/2","module":"PhoenixInlineSvg.Helpers","type":"function","doc":"Returns a safe HTML string with the contents of the SVG file using the default_collection configuration. Examples &lt;%= svg_image(@conn, &quot;home&quot;) %&gt; &lt;%= svg_image(YourAppWeb.Endpoint, &quot;home&quot;) %&gt; Will result in the output: &lt;svg&gt;...&lt;/svg&gt; The main function is svg_image/4."},{"ref":"PhoenixInlineSvg.Helpers.html#svg_image/3","title":"PhoenixInlineSvg.Helpers.svg_image/3","module":"PhoenixInlineSvg.Helpers","type":"function","doc":"Returns a safe HTML string with the contents of the SVG file after inserting the given HTML attributes. Examples &lt;%= svg_image(@conn, &quot;home&quot;, class: &quot;logo&quot;, id: &quot;bounce-animation&quot;) %&gt; &lt;%= svg_image(YourAppWeb.Endpoint, &quot;home&quot;, class: &quot;logo&quot;, id: &quot;bounce-animation&quot;) %&gt; Will result in the output: &lt;svg class=&quot;logo&quot; id=&quot;bounce-animation&quot;&gt;...&lt;/svg&gt; The main function is svg_image/4."},{"ref":"PhoenixInlineSvg.Helpers.html#svg_image/4","title":"PhoenixInlineSvg.Helpers.svg_image/4","module":"PhoenixInlineSvg.Helpers","type":"function","doc":"Returns a safe HTML string with the contents of the SVG file for the given collection after inserting the given HTML attributes. Examples &lt;%= svg_image(@conn, &quot;user&quot;, &quot;fontawesome&quot;) %&gt; &lt;%= svg_image(YourAppWeb.Endpoint, &quot;user&quot;, &quot;fontawesome&quot;) %&gt; Will result in the output: &lt;svg&gt;...&lt;/svg&gt; Find SVG file inside of &quot;icons&quot; folder and add class &quot;fa fa-share&quot; and id &quot;bounce-animation&quot; &lt;%= svg_image(@conn, &quot;user&quot;, &quot;icons&quot;, class: &quot;fa fa-share&quot;, id: &quot;bounce-animation&quot;) %&gt; &lt;%= svg_image(YourAppWeb.Endpoint, &quot;user&quot;, &quot;icons&quot;, class: &quot;fa fa-share&quot;, id: &quot;bounce-animation&quot;) %&gt; Will result in the output: &lt;svg class=&quot;fa fa-share&quot; id=&quot;bounce-animation&quot;&gt;...&lt;/svg&gt;"},{"ref":"readme.html","title":"Phoenix Inline SVG","module":"readme","type":"extras","doc":"Phoenix Inline SVG Adds support for inline SVG files in Phoenix Framework. This package allows you to quickly and easily add SVG files into your HTML templates in Phoenix Framework."},{"ref":"readme.html#installation","title":"Phoenix Inline SVG - Installation","module":"readme","type":"extras","doc":"Add phoenix_inline_svg to your list of dependencies in mix.exs: def deps do [{:phoenix_inline_svg, &quot;~&gt; 1.3&quot;}] end"},{"ref":"readme.html#usage","title":"Phoenix Inline SVG - Usage","module":"readme","type":"extras","doc":"def view do quote do ... use PhoenixInlineSvg.Helpers, otp_app: :my_app_name ... end end Generic Collection &lt;%= svg_image(&quot;home&quot;) %&gt; Where home is the name of the SVG file you want to load. This will output the HTML: &lt;svg&gt;...&lt;/svg&gt; By default this will load the SVG file from: /priv/static/svg/generic/home.svg Collections There is an optional argument in the function to allow for breaking up SVG files into collections (or folders on the filesystem): &lt;%= svg_image(&quot;user&quot;, &quot;fontawesome&quot;) %&gt; Will result in the output: &lt;svg&gt;...&lt;/svg&gt; This will load the SVG file from: /priv/static/svg/fontawesome/user.svg HTML attributes You can also pass optional HTML attributes into the function to set those properties on the SVG. &lt;%= svg_image(&quot;home&quot;, class: &quot;logo&quot;, id: &quot;bounce-animation&quot;) %&gt; Will result in the output: &lt;svg class=&quot;logo&quot; id=&quot;bounce-animation&quot;&gt;...&lt;/svg&gt;"},{"ref":"readme.html#configuration-options","title":"Phoenix Inline SVG - Configuration Options","module":"readme","type":"extras","doc":"There are several optional configuration settings for adjusting this package to your needs: Directory The directory in the project to load image assets from. If you are using Exrm make sure you use a directory that is outputted to the projects lib directory after the release has been created. config :phoenix_inline_svg, dir: &quot;/priv/somewhere/&quot; The default value is /priv/static/svg/ and is a directory relative to the project&#39;s root directory. Default Collection The name of the collection to use by default. This is usually overridden to be the primary collection of images. config :phoenix_inline_svg, default_collection: &quot;fontawesome&quot; The default value is generic Not Found What should be dispayed in the &lt;i&gt; element when there is no SVG file found. config :phoenix_inline_svg, not_found: &quot;&lt;p&gt;Oh No!&lt;/p&gt;&quot; The default value is: &lt;svg viewbox=&#39;0 0 60 60&#39;&gt; &lt;text x=&#39;0&#39; y=&#39;40&#39; font-size=&#39;30&#39; font-weight=&#39;bold&#39; font-family=&#39;monospace&#39;&gt;Err&lt;/text&gt; &lt;/svg&gt;"},{"ref":"readme.html#old-style","title":"Phoenix Inline SVG - Old Style","module":"readme","type":"extras","doc":"To use this package in the old style, add the following line to the view function in your my_app_web.ex file. def view do quote do ... import PhoenixInlineSvg.Helpers ... end end Caching SVGs Since the old style will read the images from disk on every request, you can enable caching through a GenServer. For Use with Import Only: If you use the new style, use PhoenixInlineSvg.Helpers, otp_app: :my_app_name, your images are already cached since they are loaded into functions at compile time. Add the following code to the file lib/__MY_APP_NAME__/inline_svg_cache.ex. Note: Be sure to change __MYAPP_NAME\\_ to the name of your app. defmodule __MY_APP_NAME__.InlineSvgCache do use GenServer alias PhoenixInlineSvg.Helpers # # Client API # def start_link() do GenServer.start_link(__MODULE__, [], name: __MODULE__) end def svg_image(conn, svg, collection \\\\ nil) do svg_name = &quot;\#{collection}/\#{svg}&quot; case lookup(svg_name) do {:ok, data} -&gt; data {:error} -&gt; data = if collection != nil do Helpers.svg_image(conn, svg, collection) else Helpers.svg_image(conn, svg) end insert(svg_name, data) data end end def lookup(name) do GenServer.call(__MODULE__, {:lookup, name}) end def insert(name, data) do GenServer.cast(__MODULE__, {:insert, name, data}) end # # Server API # def init(_) do :ets.new(:svg_image, [:named_table, read_concurrency: true]) {:ok, %{}} end def handle_call({:lookup, name}, _from, state) do data = case :ets.lookup(:svg_image, name) do [{^name, data}] -&gt; {:ok, data} [] -&gt; {:error} end {:reply, data, state} end def handle_cast({:insert, name, data}, state) do :ets.insert(:svg_image, {name, data}) {:noreply, state} end end"}]